@@ -1,6 +1,6 @@
 /* -*- mode: C; c-file-style: "gnu"; indent-tabs-mode: nil; -*- */
 /*
- * Copyright (C) 2013, 2014, 2015 Red Hat, Inc.
+ * Copyright © 2013 – 2017 Red Hat, Inc.
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -23,6 +23,12 @@
 #ifndef __GOA_PROVIDER_PRIV_H__
 #define __GOA_PROVIDER_PRIV_H__
 
+#include <gio/gio.h>
+#include <goa/goa.h>
+#include <goabackend/goaprovider.h>
+#include <goabackend/goabackendenums.h>
+#include <gtk/gtk.h>
+
 G_BEGIN_DECLS
 
 /**
@@ -31,12 +37,6 @@ G_BEGIN_DECLS
  * The #GoaProvider structure contains only private data and should
  * only be accessed using the provided API.
  */
-struct _GoaProvider
-{
-  /*< private >*/
-  GObject parent_instance;
-  GoaProviderPrivate *priv;
-};
 
 /**
  * GoaProviderClass:
@@ -106,8 +106,8 @@ struct _GoaProviderClass
                                                            GoaClient              *client,
                                                            GoaObject              *object,
                                                            GtkBox                 *vbox,
-                                                           GtkGrid                *grid,
-                                                           GtkGrid                *dummy);
+                                                           GtkGrid                *dummy1,
+                                                           GtkGrid                *dummy2);
 };
 
 /**
